@@ -12,12 +12,29 @@
  * SOFTWARE.
  */
 
+extern crate dmntk_common;
+extern crate dmntk_evaluator;
+extern crate dmntk_feel;
+extern crate serde;
+#[cfg(feature = "bin")]
+#[macro_use]
+extern crate serde_derive;
+extern crate serde_yaml;
+
+#[cfg(feature = "bin")]
+mod cli;
+
+#[cfg(feature = "bin")]
+mod actions;
+
+/// Main entrypoint of the library.
 #[cfg(not(feature = "bin"))]
 fn main() {
   println!("Decision Model and Notation Toolkit needs be compiled with --features=bin");
 }
 
+/// Main entrypoint of the application.
 #[cfg(feature = "bin")]
 fn main() {
-  println!("Decision Model and Notation");
+  actions::action()
 }
